@@ -19,14 +19,13 @@ from ..models import Credentials, UserMeta
 
 
 STORAGE_VERSION = 1
-STORAGE_KEY = 'auth_provider.homeassistant'
+STORAGE_KEY = "auth_provider.homeassistant"
 
 
 def _disallow_id(conf: Dict[str, Any]) -> Dict[str, Any]:
     """Disallow ID in config."""
     if CONF_ID in conf:
-        raise vol.Invalid(
-            'ID is not allowed for the homeassistant auth provider.')
+        raise vol.Invalid("ID is not allowed for the homeassistant auth provider.")
 
     return conf
 
@@ -51,8 +50,9 @@ class Data:
     def __init__(self, hass: HomeAssistant) -> None:
         """Initialize the user data store."""
         self.hass = hass
-        self._store = hass.helpers.storage.Store(STORAGE_VERSION, STORAGE_KEY,
-                                                 private=True)
+        self._store = hass.helpers.storage.Store(
+            STORAGE_VERSION, STORAGE_KEY, private=True
+        )
         self._data = None  # type: Optional[Dict[str, Any]]
         # Legacy mode will allow usernames to start/end with whitespace
         # and will compare usernames case-insensitive.
@@ -72,14 +72,12 @@ class Data:
         data = await self._store.async_load()
 
         if data is None:
-            data = {
-                'users': []
-            }
+            data = {"users": []}
 
         seen = set()  # type: Set[str]
 
-        for user in data['users']:
-            username = user['username']
+        for user in data["users"]:
+            username = user["username"]
 
             # check if we have duplicates
             folded = username.casefold()
@@ -90,7 +88,9 @@ class Data:
                 logging.getLogger(__name__).warning(
                     "Home Assistant auth provider is running in legacy mode "
                     "because we detected usernames that are case-insensitive"
-                    "equivalent. Please change the username: '%s'.", username)
+                    "equivalent. Please change the username: '%s'.",
+                    username,
+                )
 
                 break
 
@@ -103,7 +103,9 @@ class Data:
                 logging.getLogger(__name__).warning(
                     "Home Assistant auth provider is running in legacy mode "
                     "because we detected usernames that start or end in a "
-                    "space. Please change the username: '%s'.", username)
+                    "space. Please change the username: '%s'.",
+                    username,
+                )
 
                 break
 
@@ -112,7 +114,7 @@ class Data:
     @property
     def users(self) -> List[Dict[str, str]]:
         """Return users."""
-        return self._data['users']  # type: ignore
+        return self._data["users"]  # type: ignore
 
     def validate_login(self, username: str, password: str) -> None:
         """Validate a username and password.
@@ -120,32 +122,30 @@ class Data:
         Raises InvalidAuth if auth invalid.
         """
         username = self.normalize_username(username)
-        dummy = b'$2b$12$CiuFGszHx9eNHxPuQcwBWez4CwDTOcLTX5CbOpV6gef2nYuXkY7BO'
+        dummy = b"$2b$12$CiuFGszHx9eNHxPuQcwBWez4CwDTOcLTX5CbOpV6gef2nYuXkY7BO"
         found = None
 
         # Compare all users to avoid timing attacks.
         for user in self.users:
-            if self.normalize_username(user['username']) == username:
+            if self.normalize_username(user["username"]) == username:
                 found = user
 
         if found is None:
             # check a hash to make timing the same as if user was found
-            bcrypt.checkpw(b'foo',
-                           dummy)
+            bcrypt.checkpw(b"foo", dummy)
             raise InvalidAuth
 
-        user_hash = base64.b64decode(found['password'])
+        user_hash = base64.b64decode(found["password"])
 
         # bcrypt.checkpw is timing-safe
-        if not bcrypt.checkpw(password.encode(),
-                              user_hash):
+        if not bcrypt.checkpw(password.encode(), user_hash):
             raise InvalidAuth
 
     # pylint: disable=no-self-use
     def hash_password(self, password: str, for_storage: bool = False) -> bytes:
         """Encode a password."""
-        hashed = bcrypt.hashpw(password.encode(), bcrypt.gensalt(rounds=12)) \
-            # type: bytes
+        hashed: bytes = bcrypt.hashpw(password.encode(), bcrypt.gensalt(rounds=12))
+
         if for_storage:
             hashed = base64.b64encode(hashed)
         return hashed
@@ -154,14 +154,17 @@ class Data:
         """Add a new authenticated user/pass."""
         username = self.normalize_username(username)
 
-        if any(self.normalize_username(user['username']) == username
-               for user in self.users):
+        if any(
+            self.normalize_username(user["username"]) == username for user in self.users
+        ):
             raise InvalidUser
 
-        self.users.append({
-            'username': username,
-            'password': self.hash_password(password, True).decode(),
-        })
+        self.users.append(
+            {
+                "username": username,
+                "password": self.hash_password(password, True).decode(),
+            }
+        )
 
     @callback
     def async_remove_auth(self, username: str) -> None:
@@ -170,7 +173,7 @@ class Data:
 
         index = None
         for i, user in enumerate(self.users):
-            if self.normalize_username(user['username']) == username:
+            if self.normalize_username(user["username"]) == username:
                 index = i
                 break
 
@@ -187,9 +190,8 @@ class Data:
         username = self.normalize_username(username)
 
         for user in self.users:
-            if self.normalize_username(user['username']) == username:
-                user['password'] = self.hash_password(
-                    new_password, True).decode()
+            if self.normalize_username(user["username"]) == username:
+                user["password"] = self.hash_password(new_password, True).decode()
                 break
         else:
             raise InvalidUser
@@ -199,11 +201,11 @@ class Data:
         await self._store.async_save(self._data)
 
 
-@AUTH_PROVIDERS.register('homeassistant')
+@AUTH_PROVIDERS.register("homeassistant")
 class HassAuthProvider(AuthProvider):
     """Auth provider based on a local storage of users in HASS config dir."""
 
-    DEFAULT_TITLE = 'Home Assistant Local'
+    DEFAULT_TITLE = "Home Assistant Local"
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Initialize an Home Assistant auth provider."""
@@ -221,8 +223,7 @@ class HassAuthProvider(AuthProvider):
             await data.async_load()
             self.data = data
 
-    async def async_login_flow(
-            self, context: Optional[Dict]) -> LoginFlow:
+    async def async_login_flow(self, context: Optional[Dict]) -> LoginFlow:
         """Return a flow to login."""
         return HassLoginFlow(self)
 
@@ -233,41 +234,41 @@ class HassAuthProvider(AuthProvider):
             assert self.data is not None
 
         await self.hass.async_add_executor_job(
-            self.data.validate_login, username, password)
+            self.data.validate_login, username, password
+        )
 
     async def async_get_or_create_credentials(
-            self, flow_result: Dict[str, str]) -> Credentials:
+        self, flow_result: Dict[str, str]
+    ) -> Credentials:
         """Get credentials based on the flow result."""
         if self.data is None:
             await self.async_initialize()
             assert self.data is not None
 
         norm_username = self.data.normalize_username
-        username = norm_username(flow_result['username'])
+        username = norm_username(flow_result["username"])
 
         for credential in await self.async_credentials():
-            if norm_username(credential.data['username']) == username:
+            if norm_username(credential.data["username"]) == username:
                 return credential
 
         # Create new credentials.
-        return self.async_create_credentials({
-            'username': username
-        })
+        return self.async_create_credentials({"username": username})
 
     async def async_user_meta_for_credentials(
-            self, credentials: Credentials) -> UserMeta:
+        self, credentials: Credentials
+    ) -> UserMeta:
         """Get extra info for this credential."""
-        return UserMeta(name=credentials.data['username'], is_active=True)
+        return UserMeta(name=credentials.data["username"], is_active=True)
 
-    async def async_will_remove_credentials(
-            self, credentials: Credentials) -> None:
+    async def async_will_remove_credentials(self, credentials: Credentials) -> None:
         """When credentials get removed, also remove the auth."""
         if self.data is None:
             await self.async_initialize()
             assert self.data is not None
 
         try:
-            self.data.async_remove_auth(credentials.data['username'])
+            self.data.async_remove_auth(credentials.data["username"])
             await self.data.async_save()
         except InvalidUser:
             # Can happen if somehow we didn't clean up a credential
@@ -278,29 +279,27 @@ class HassLoginFlow(LoginFlow):
     """Handler for the login flow."""
 
     async def async_step_init(
-            self, user_input: Optional[Dict[str, str]] = None) \
-            -> Dict[str, Any]:
+        self, user_input: Optional[Dict[str, str]] = None
+    ) -> Dict[str, Any]:
         """Handle the step of the form."""
         errors = {}
 
         if user_input is not None:
             try:
-                await cast(HassAuthProvider, self._auth_provider)\
-                    .async_validate_login(user_input['username'],
-                                          user_input['password'])
+                await cast(HassAuthProvider, self._auth_provider).async_validate_login(
+                    user_input["username"], user_input["password"]
+                )
             except InvalidAuth:
-                errors['base'] = 'invalid_auth'
+                errors["base"] = "invalid_auth"
 
             if not errors:
-                user_input.pop('password')
+                user_input.pop("password")
                 return await self.async_finish(user_input)
 
         schema = OrderedDict()  # type: Dict[str, type]
-        schema['username'] = str
-        schema['password'] = str
+        schema["username"] = str
+        schema["password"] = str
 
         return self.async_show_form(
-            step_id='init',
-            data_schema=vol.Schema(schema),
-            errors=errors,
+            step_id="init", data_schema=vol.Schema(schema), errors=errors
         )
