@@ -13,11 +13,7 @@ from homeassistant.const import (
     STATE_UNLOCKED,
 )
 import homeassistant.components.climate.const as climate
-from homeassistant.components import (
-    light,
-    fan,
-    cover,
-)
+from homeassistant.components import light, fan, cover
 import homeassistant.util.color as color_util
 
 from .const import (
@@ -85,35 +81,35 @@ class AlexaCapibility:
     def serialize_discovery(self):
         """Serialize according to the Discovery API."""
         result = {
-            'type': 'AlexaInterface',
-            'interface': self.name(),
-            'version': '3',
-            'properties': {
-                'supported': self.properties_supported(),
-                'proactivelyReported': self.properties_proactively_reported(),
-                'retrievable': self.properties_retrievable(),
+            "type": "AlexaInterface",
+            "interface": self.name(),
+            "version": "3",
+            "properties": {
+                "supported": self.properties_supported(),
+                "proactivelyReported": self.properties_proactively_reported(),
+                "retrievable": self.properties_retrievable(),
             },
         }
 
         # pylint: disable=assignment-from-none
         supports_deactivation = self.supports_deactivation()
         if supports_deactivation is not None:
-            result['supportsDeactivation'] = supports_deactivation
+            result["supportsDeactivation"] = supports_deactivation
         return result
 
     def serialize_properties(self):
         """Return properties serialized for an API response."""
         for prop in self.properties_supported():
-            prop_name = prop['name']
+            prop_name = prop["name"]
             # pylint: disable=assignment-from-no-return
             prop_value = self.get_property(prop_name)
             if prop_value is not None:
                 yield {
-                    'name': prop_name,
-                    'namespace': self.name(),
-                    'value': prop_value,
-                    'timeOfSample': datetime.now().strftime(DATE_FORMAT),
-                    'uncertaintyInMilliseconds': 0
+                    "name": prop_name,
+                    "namespace": self.name(),
+                    "value": prop_value,
+                    "timeOfSample": datetime.now().strftime(DATE_FORMAT),
+                    "uncertaintyInMilliseconds": 0,
                 }
 
 
@@ -130,11 +126,11 @@ class AlexaEndpointHealth(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.EndpointHealth'
+        return "Alexa.EndpointHealth"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'connectivity'}]
+        return [{"name": "connectivity"}]
 
     def properties_proactively_reported(self):
         """Return True if properties asynchronously reported."""
@@ -146,12 +142,12 @@ class AlexaEndpointHealth(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'connectivity':
+        if name != "connectivity":
             raise UnsupportedProperty(name)
 
         if self.entity.state == STATE_UNAVAILABLE:
-            return {'value': 'UNREACHABLE'}
-        return {'value': 'OK'}
+            return {"value": "UNREACHABLE"}
+        return {"value": "OK"}
 
 
 class AlexaPowerController(AlexaCapibility):
@@ -162,11 +158,11 @@ class AlexaPowerController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.PowerController'
+        return "Alexa.PowerController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'powerState'}]
+        return [{"name": "powerState"}]
 
     def properties_proactively_reported(self):
         """Return True if properties asynchronously reported."""
@@ -178,7 +174,7 @@ class AlexaPowerController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'powerState':
+        if name != "powerState":
             raise UnsupportedProperty(name)
 
         if self.entity.domain == climate.DOMAIN:
@@ -187,7 +183,7 @@ class AlexaPowerController(AlexaCapibility):
         else:
             is_on = self.entity.state != STATE_OFF
 
-        return 'ON' if is_on else 'OFF'
+        return "ON" if is_on else "OFF"
 
 
 class AlexaLockController(AlexaCapibility):
@@ -198,11 +194,11 @@ class AlexaLockController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.LockController'
+        return "Alexa.LockController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'lockState'}]
+        return [{"name": "lockState"}]
 
     def properties_retrievable(self):
         """Return True if properties can be retrieved."""
@@ -214,14 +210,14 @@ class AlexaLockController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'lockState':
+        if name != "lockState":
             raise UnsupportedProperty(name)
 
         if self.entity.state == STATE_LOCKED:
-            return 'LOCKED'
+            return "LOCKED"
         if self.entity.state == STATE_UNLOCKED:
-            return 'UNLOCKED'
-        return 'JAMMED'
+            return "UNLOCKED"
+        return "JAMMED"
 
 
 class AlexaSceneController(AlexaCapibility):
@@ -237,7 +233,7 @@ class AlexaSceneController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.SceneController'
+        return "Alexa.SceneController"
 
 
 class AlexaBrightnessController(AlexaCapibility):
@@ -248,11 +244,11 @@ class AlexaBrightnessController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.BrightnessController'
+        return "Alexa.BrightnessController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'brightness'}]
+        return [{"name": "brightness"}]
 
     def properties_proactively_reported(self):
         """Return True if properties asynchronously reported."""
@@ -264,10 +260,10 @@ class AlexaBrightnessController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'brightness':
+        if name != "brightness":
             raise UnsupportedProperty(name)
-        if 'brightness' in self.entity.attributes:
-            return round(self.entity.attributes['brightness'] / 255.0 * 100)
+        if "brightness" in self.entity.attributes:
+            return round(self.entity.attributes["brightness"] / 255.0 * 100)
         return 0
 
 
@@ -279,11 +275,11 @@ class AlexaColorController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.ColorController'
+        return "Alexa.ColorController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'color'}]
+        return [{"name": "color"}]
 
     def properties_retrievable(self):
         """Return True if properties can be retrieved."""
@@ -291,17 +287,15 @@ class AlexaColorController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'color':
+        if name != "color":
             raise UnsupportedProperty(name)
 
-        hue, saturation = self.entity.attributes.get(
-            light.ATTR_HS_COLOR, (0, 0))
+        hue, saturation = self.entity.attributes.get(light.ATTR_HS_COLOR, (0, 0))
 
         return {
-            'hue': hue,
-            'saturation': saturation / 100.0,
-            'brightness': self.entity.attributes.get(
-                light.ATTR_BRIGHTNESS, 0) / 255.0,
+            "hue": hue,
+            "saturation": saturation / 100.0,
+            "brightness": self.entity.attributes.get(light.ATTR_BRIGHTNESS, 0) / 255.0,
         }
 
 
@@ -313,11 +307,11 @@ class AlexaColorTemperatureController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.ColorTemperatureController'
+        return "Alexa.ColorTemperatureController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'colorTemperatureInKelvin'}]
+        return [{"name": "colorTemperatureInKelvin"}]
 
     def properties_retrievable(self):
         """Return True if properties can be retrieved."""
@@ -325,11 +319,12 @@ class AlexaColorTemperatureController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'colorTemperatureInKelvin':
+        if name != "colorTemperatureInKelvin":
             raise UnsupportedProperty(name)
-        if 'color_temp' in self.entity.attributes:
+        if "color_temp" in self.entity.attributes:
             return color_util.color_temperature_mired_to_kelvin(
-                self.entity.attributes['color_temp'])
+                self.entity.attributes["color_temp"]
+            )
         return 0
 
 
@@ -341,11 +336,11 @@ class AlexaPercentageController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.PercentageController'
+        return "Alexa.PercentageController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'percentage'}]
+        return [{"name": "percentage"}]
 
     def properties_retrievable(self):
         """Return True if properties can be retrieved."""
@@ -353,7 +348,7 @@ class AlexaPercentageController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'percentage':
+        if name != "percentage":
             raise UnsupportedProperty(name)
 
         if self.entity.domain == fan.DOMAIN:
@@ -375,7 +370,7 @@ class AlexaSpeaker(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.Speaker'
+        return "Alexa.Speaker"
 
 
 class AlexaStepSpeaker(AlexaCapibility):
@@ -386,7 +381,7 @@ class AlexaStepSpeaker(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.StepSpeaker'
+        return "Alexa.StepSpeaker"
 
 
 class AlexaPlaybackController(AlexaCapibility):
@@ -397,7 +392,7 @@ class AlexaPlaybackController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.PlaybackController'
+        return "Alexa.PlaybackController"
 
 
 class AlexaInputController(AlexaCapibility):
@@ -408,7 +403,7 @@ class AlexaInputController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.InputController'
+        return "Alexa.InputController"
 
 
 class AlexaTemperatureSensor(AlexaCapibility):
@@ -424,11 +419,11 @@ class AlexaTemperatureSensor(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.TemperatureSensor'
+        return "Alexa.TemperatureSensor"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'temperature'}]
+        return [{"name": "temperature"}]
 
     def properties_proactively_reported(self):
         """Return True if properties asynchronously reported."""
@@ -440,19 +435,15 @@ class AlexaTemperatureSensor(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'temperature':
+        if name != "temperature":
             raise UnsupportedProperty(name)
 
         unit = self.entity.attributes.get(ATTR_UNIT_OF_MEASUREMENT)
         temp = self.entity.state
         if self.entity.domain == climate.DOMAIN:
             unit = self.hass.config.units.temperature_unit
-            temp = self.entity.attributes.get(
-                climate.ATTR_CURRENT_TEMPERATURE)
-        return {
-            'value': float(temp),
-            'scale': API_TEMP_UNITS[unit],
-        }
+            temp = self.entity.attributes.get(climate.ATTR_CURRENT_TEMPERATURE)
+        return {"value": float(temp), "scale": API_TEMP_UNITS[unit]}
 
 
 class AlexaContactSensor(AlexaCapibility):
@@ -473,11 +464,11 @@ class AlexaContactSensor(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.ContactSensor'
+        return "Alexa.ContactSensor"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'detectionState'}]
+        return [{"name": "detectionState"}]
 
     def properties_proactively_reported(self):
         """Return True if properties asynchronously reported."""
@@ -489,12 +480,12 @@ class AlexaContactSensor(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'detectionState':
+        if name != "detectionState":
             raise UnsupportedProperty(name)
 
         if self.entity.state == STATE_ON:
-            return 'DETECTED'
-        return 'NOT_DETECTED'
+            return "DETECTED"
+        return "NOT_DETECTED"
 
 
 class AlexaMotionSensor(AlexaCapibility):
@@ -510,11 +501,11 @@ class AlexaMotionSensor(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.MotionSensor'
+        return "Alexa.MotionSensor"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        return [{'name': 'detectionState'}]
+        return [{"name": "detectionState"}]
 
     def properties_proactively_reported(self):
         """Return True if properties asynchronously reported."""
@@ -526,12 +517,12 @@ class AlexaMotionSensor(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name != 'detectionState':
+        if name != "detectionState":
             raise UnsupportedProperty(name)
 
         if self.entity.state == STATE_ON:
-            return 'DETECTED'
-        return 'NOT_DETECTED'
+            return "DETECTED"
+        return "NOT_DETECTED"
 
 
 class AlexaThermostatController(AlexaCapibility):
@@ -547,17 +538,17 @@ class AlexaThermostatController(AlexaCapibility):
 
     def name(self):
         """Return the Alexa API name of this interface."""
-        return 'Alexa.ThermostatController'
+        return "Alexa.ThermostatController"
 
     def properties_supported(self):
         """Return what properties this entity supports."""
-        properties = [{'name': 'thermostatMode'}]
+        properties = [{"name": "thermostatMode"}]
         supported = self.entity.attributes.get(ATTR_SUPPORTED_FEATURES, 0)
         if supported & climate.SUPPORT_TARGET_TEMPERATURE:
-            properties.append({'name': 'targetSetpoint'})
+            properties.append({"name": "targetSetpoint"})
         if supported & climate.SUPPORT_TARGET_TEMPERATURE_RANGE:
-            properties.append({'name': 'lowerSetpoint'})
-            properties.append({'name': 'upperSetpoint'})
+            properties.append({"name": "lowerSetpoint"})
+            properties.append({"name": "upperSetpoint"})
         return properties
 
     def properties_proactively_reported(self):
@@ -570,7 +561,7 @@ class AlexaThermostatController(AlexaCapibility):
 
     def get_property(self, name):
         """Read and return a property."""
-        if name == 'thermostatMode':
+        if name == "thermostatMode":
             preset = self.entity.attributes.get(climate.ATTR_PRESET_MODE)
 
             if preset in API_THERMOSTAT_PRESETS:
@@ -580,17 +571,19 @@ class AlexaThermostatController(AlexaCapibility):
                 if mode is None:
                     _LOGGER.error(
                         "%s (%s) has unsupported state value '%s'",
-                        self.entity.entity_id, type(self.entity),
-                        self.entity.state)
+                        self.entity.entity_id,
+                        type(self.entity),
+                        self.entity.state,
+                    )
                     raise UnsupportedProperty(name)
             return mode
 
         unit = self.hass.config.units.temperature_unit
-        if name == 'targetSetpoint':
+        if name == "targetSetpoint":
             temp = self.entity.attributes.get(ATTR_TEMPERATURE)
-        elif name == 'lowerSetpoint':
+        elif name == "lowerSetpoint":
             temp = self.entity.attributes.get(climate.ATTR_TARGET_TEMP_LOW)
-        elif name == 'upperSetpoint':
+        elif name == "upperSetpoint":
             temp = self.entity.attributes.get(climate.ATTR_TARGET_TEMP_HIGH)
         else:
             raise UnsupportedProperty(name)
@@ -598,7 +591,4 @@ class AlexaThermostatController(AlexaCapibility):
         if temp is None:
             return None
 
-        return {
-            'value': float(temp),
-            'scale': API_TEMP_UNITS[unit],
-        }
+        return {"value": float(temp), "scale": API_TEMP_UNITS[unit]}
