@@ -8,19 +8,26 @@ import homeassistant.helpers.config_validation as cv
 
 from . import EditIdBasedConfigView
 
-CONFIG_PATH = 'automations.yaml'
+CONFIG_PATH = "automations.yaml"
 
 
 async def async_setup(hass):
     """Set up the Automation config API."""
+
     async def hook(hass):
         """post_write_hook for Config View that reloads automations."""
         await hass.services.async_call(DOMAIN, SERVICE_RELOAD)
 
-    hass.http.register_view(EditAutomationConfigView(
-        DOMAIN, 'config', CONFIG_PATH, cv.string,
-        PLATFORM_SCHEMA, post_write_hook=hook
-    ))
+    hass.http.register_view(
+        EditAutomationConfigView(
+            DOMAIN,
+            "config",
+            CONFIG_PATH,
+            cv.string,
+            PLATFORM_SCHEMA,
+            post_write_hook=hook,
+        )
+    )
     return True
 
 
@@ -46,7 +53,7 @@ class EditAutomationConfigView(EditIdBasedConfigView):
 
         # Iterate through some keys that we want to have ordered in the output
         updated_value = OrderedDict()
-        for key in ('id', 'alias', 'trigger', 'condition', 'action'):
+        for key in ("id", "alias", "trigger", "condition", "action"):
             if key in cur_value:
                 updated_value[key] = cur_value[key]
             if key in new_value:
