@@ -22,6 +22,8 @@ from homeassistant.loader import bind_hass
 from .storage import async_setup_frontend_storage
 
 
+# mypy: allow-incomplete-defs, allow-untyped-defs, no-check-untyped-defs
+
 # Fix mimetypes for borked Windows machines
 # https://github.com/home-assistant/home-assistant-polymer/issues/3336
 mimetypes.add_type("text/css", ".css")
@@ -45,7 +47,14 @@ MANIFEST_JSON = {
     "description": "Home automation platform that puts local control and privacy first.",
     "dir": "ltr",
     "display": "standalone",
-    "icons": [],
+    "icons": [
+        {
+            "src": "/static/icons/favicon-{size}x{size}.png".format(size=size),
+            "sizes": "{size}x{size}".format(size=size),
+            "type": "image/png",
+        }
+        for size in (192, 384, 512, 1024)
+    ],
     "lang": "en-US",
     "name": "Home Assistant",
     "short_name": "Assistant",
@@ -53,15 +62,6 @@ MANIFEST_JSON = {
     "theme_color": DEFAULT_THEME_COLOR,
 }
 
-for size in (192, 384, 512, 1024):
-    MANIFEST_JSON["icons"].append(
-        {
-            "src": "/static/icons/favicon-{size}x{size}.png".format(size=size),
-            "sizes": "{size}x{size}".format(size=size),
-            "type": "image/png",
-        }
-    )
-
 DATA_PANELS = "frontend_panels"
 DATA_JS_VERSION = "frontend_js_version"
 DATA_EXTRA_HTML_URL = "frontend_extra_html_url"
