@@ -4,41 +4,63 @@ import logging
 import voluptuous as vol
 
 from homeassistant.const import (
-    ATTR_ASSUMED_STATE, ATTR_ENTITY_ID, ATTR_SUPPORTED_FEATURES, CONF_ENTITIES,
-    CONF_NAME, STATE_CLOSED)
+    ATTR_ASSUMED_STATE,
+    ATTR_ENTITY_ID,
+    ATTR_SUPPORTED_FEATURES,
+    CONF_ENTITIES,
+    CONF_NAME,
+    STATE_CLOSED,
+)
 from homeassistant.core import callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.event import async_track_state_change
 
 from homeassistant.components.cover import (
-    ATTR_CURRENT_POSITION, ATTR_CURRENT_TILT_POSITION, ATTR_POSITION,
-    ATTR_TILT_POSITION, DOMAIN, PLATFORM_SCHEMA, SERVICE_CLOSE_COVER,
-    SERVICE_CLOSE_COVER_TILT, SERVICE_OPEN_COVER, SERVICE_OPEN_COVER_TILT,
-    SERVICE_SET_COVER_POSITION, SERVICE_SET_COVER_TILT_POSITION,
-    SERVICE_STOP_COVER, SERVICE_STOP_COVER_TILT, SUPPORT_CLOSE,
-    SUPPORT_CLOSE_TILT, SUPPORT_OPEN, SUPPORT_OPEN_TILT, SUPPORT_SET_POSITION,
-    SUPPORT_SET_TILT_POSITION, SUPPORT_STOP, SUPPORT_STOP_TILT, CoverDevice)
+    ATTR_CURRENT_POSITION,
+    ATTR_CURRENT_TILT_POSITION,
+    ATTR_POSITION,
+    ATTR_TILT_POSITION,
+    DOMAIN,
+    PLATFORM_SCHEMA,
+    SERVICE_CLOSE_COVER,
+    SERVICE_CLOSE_COVER_TILT,
+    SERVICE_OPEN_COVER,
+    SERVICE_OPEN_COVER_TILT,
+    SERVICE_SET_COVER_POSITION,
+    SERVICE_SET_COVER_TILT_POSITION,
+    SERVICE_STOP_COVER,
+    SERVICE_STOP_COVER_TILT,
+    SUPPORT_CLOSE,
+    SUPPORT_CLOSE_TILT,
+    SUPPORT_OPEN,
+    SUPPORT_OPEN_TILT,
+    SUPPORT_SET_POSITION,
+    SUPPORT_SET_TILT_POSITION,
+    SUPPORT_STOP,
+    SUPPORT_STOP_TILT,
+    CoverDevice,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-KEY_OPEN_CLOSE = 'open_close'
-KEY_STOP = 'stop'
-KEY_POSITION = 'position'
+KEY_OPEN_CLOSE = "open_close"
+KEY_STOP = "stop"
+KEY_POSITION = "position"
 
-DEFAULT_NAME = 'Cover Group'
+DEFAULT_NAME = "Cover Group"
 
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Required(CONF_ENTITIES): cv.entities_domain(DOMAIN),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Required(CONF_ENTITIES): cv.entities_domain(DOMAIN),
+    }
+)
 
 
-async def async_setup_platform(hass, config, async_add_entities,
-                               discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the Group Cover platform."""
-    async_add_entities(
-        [CoverGroup(config[CONF_NAME], config[CONF_ENTITIES])])
+    async_add_entities([CoverGroup(config[CONF_NAME], config[CONF_ENTITIES])])
 
 
 class CoverGroup(CoverDevice):
@@ -54,14 +76,13 @@ class CoverGroup(CoverDevice):
         self._assumed_state = True
 
         self._entities = entities
-        self._covers = {KEY_OPEN_CLOSE: set(), KEY_STOP: set(),
-                        KEY_POSITION: set()}
-        self._tilts = {KEY_OPEN_CLOSE: set(), KEY_STOP: set(),
-                       KEY_POSITION: set()}
+        self._covers = {KEY_OPEN_CLOSE: set(), KEY_STOP: set(), KEY_POSITION: set()}
+        self._tilts = {KEY_OPEN_CLOSE: set(), KEY_STOP: set(), KEY_POSITION: set()}
 
     @callback
-    def update_supported_features(self, entity_id, old_state, new_state,
-                                  update_state=True):
+    def update_supported_features(
+        self, entity_id, old_state, new_state, update_state=True
+    ):
         """Update dictionaries with supported features."""
         if not new_state:
             for values in self._covers.values():
@@ -107,10 +128,12 @@ class CoverGroup(CoverDevice):
         """Register listeners."""
         for entity_id in self._entities:
             new_state = self.hass.states.get(entity_id)
-            self.update_supported_features(entity_id, None, new_state,
-                                           update_state=False)
-        async_track_state_change(self.hass, self._entities,
-                                 self.update_supported_features)
+            self.update_supported_features(
+                entity_id, None, new_state, update_state=False
+            )
+        async_track_state_change(
+            self.hass, self._entities, self.update_supported_features
+        )
         await self.async_update()
 
     @property
@@ -152,51 +175,63 @@ class CoverGroup(CoverDevice):
         """Move the covers up."""
         data = {ATTR_ENTITY_ID: self._covers[KEY_OPEN_CLOSE]}
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_OPEN_COVER, data, blocking=True)
+            DOMAIN, SERVICE_OPEN_COVER, data, blocking=True
+        )
 
     async def async_close_cover(self, **kwargs):
         """Move the covers down."""
         data = {ATTR_ENTITY_ID: self._covers[KEY_OPEN_CLOSE]}
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_CLOSE_COVER, data, blocking=True)
+            DOMAIN, SERVICE_CLOSE_COVER, data, blocking=True
+        )
 
     async def async_stop_cover(self, **kwargs):
         """Fire the stop action."""
         data = {ATTR_ENTITY_ID: self._covers[KEY_STOP]}
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_STOP_COVER, data, blocking=True)
+            DOMAIN, SERVICE_STOP_COVER, data, blocking=True
+        )
 
     async def async_set_cover_position(self, **kwargs):
         """Set covers position."""
-        data = {ATTR_ENTITY_ID: self._covers[KEY_POSITION],
-                ATTR_POSITION: kwargs[ATTR_POSITION]}
+        data = {
+            ATTR_ENTITY_ID: self._covers[KEY_POSITION],
+            ATTR_POSITION: kwargs[ATTR_POSITION],
+        }
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_SET_COVER_POSITION, data, blocking=True)
+            DOMAIN, SERVICE_SET_COVER_POSITION, data, blocking=True
+        )
 
     async def async_open_cover_tilt(self, **kwargs):
         """Tilt covers open."""
         data = {ATTR_ENTITY_ID: self._tilts[KEY_OPEN_CLOSE]}
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_OPEN_COVER_TILT, data, blocking=True)
+            DOMAIN, SERVICE_OPEN_COVER_TILT, data, blocking=True
+        )
 
     async def async_close_cover_tilt(self, **kwargs):
         """Tilt covers closed."""
         data = {ATTR_ENTITY_ID: self._tilts[KEY_OPEN_CLOSE]}
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_CLOSE_COVER_TILT, data, blocking=True)
+            DOMAIN, SERVICE_CLOSE_COVER_TILT, data, blocking=True
+        )
 
     async def async_stop_cover_tilt(self, **kwargs):
         """Stop cover tilt."""
         data = {ATTR_ENTITY_ID: self._tilts[KEY_STOP]}
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_STOP_COVER_TILT, data, blocking=True)
+            DOMAIN, SERVICE_STOP_COVER_TILT, data, blocking=True
+        )
 
     async def async_set_cover_tilt_position(self, **kwargs):
         """Set tilt position."""
-        data = {ATTR_ENTITY_ID: self._tilts[KEY_POSITION],
-                ATTR_TILT_POSITION: kwargs[ATTR_TILT_POSITION]}
+        data = {
+            ATTR_ENTITY_ID: self._tilts[KEY_POSITION],
+            ATTR_TILT_POSITION: kwargs[ATTR_TILT_POSITION],
+        }
         await self.hass.services.async_call(
-            DOMAIN, SERVICE_SET_COVER_TILT_POSITION, data, blocking=True)
+            DOMAIN, SERVICE_SET_COVER_TILT_POSITION, data, blocking=True
+        )
 
     async def async_update(self):
         """Update state and attributes."""
@@ -244,18 +279,18 @@ class CoverGroup(CoverDevice):
                     self._tilt_position = position
 
         supported_features = 0
-        supported_features |= SUPPORT_OPEN | SUPPORT_CLOSE \
-            if self._covers[KEY_OPEN_CLOSE] else 0
-        supported_features |= SUPPORT_STOP \
-            if self._covers[KEY_STOP] else 0
-        supported_features |= SUPPORT_SET_POSITION \
-            if self._covers[KEY_POSITION] else 0
-        supported_features |= SUPPORT_OPEN_TILT | SUPPORT_CLOSE_TILT \
-            if self._tilts[KEY_OPEN_CLOSE] else 0
-        supported_features |= SUPPORT_STOP_TILT \
-            if self._tilts[KEY_STOP] else 0
-        supported_features |= SUPPORT_SET_TILT_POSITION \
-            if self._tilts[KEY_POSITION] else 0
+        supported_features |= (
+            SUPPORT_OPEN | SUPPORT_CLOSE if self._covers[KEY_OPEN_CLOSE] else 0
+        )
+        supported_features |= SUPPORT_STOP if self._covers[KEY_STOP] else 0
+        supported_features |= SUPPORT_SET_POSITION if self._covers[KEY_POSITION] else 0
+        supported_features |= (
+            SUPPORT_OPEN_TILT | SUPPORT_CLOSE_TILT if self._tilts[KEY_OPEN_CLOSE] else 0
+        )
+        supported_features |= SUPPORT_STOP_TILT if self._tilts[KEY_STOP] else 0
+        supported_features |= (
+            SUPPORT_SET_TILT_POSITION if self._tilts[KEY_POSITION] else 0
+        )
         self._supported_features = supported_features
 
         if not self._assumed_state:
