@@ -1,4 +1,6 @@
 """Support for Homekit sensors."""
+from homekit.model.characteristics import CharacteristicsTypes
+
 from homeassistant.const import TEMP_CELSIUS
 
 from . import KNOWN_DEVICES, HomeKitEntity
@@ -6,39 +8,11 @@ from . import KNOWN_DEVICES, HomeKitEntity
 HUMIDITY_ICON = "mdi:water-percent"
 TEMP_C_ICON = "mdi:thermometer"
 BRIGHTNESS_ICON = "mdi:brightness-6"
+CO2_ICON = "mdi:periodic-table-co2"
 
 UNIT_PERCENT = "%"
 UNIT_LUX = "lux"
-
-
-async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
-    """Legacy set up platform."""
-    pass
-
-
-async def async_setup_entry(hass, config_entry, async_add_entities):
-    """Set up Homekit covers."""
-    hkid = config_entry.data["AccessoryPairingID"]
-    conn = hass.data[KNOWN_DEVICES][hkid]
-
-    def async_add_service(aid, service):
-        devtype = service["stype"]
-        info = {"aid": aid, "iid": service["iid"]}
-        if devtype == "humidity":
-            async_add_entities([HomeKitHumiditySensor(conn, info)], True)
-            return True
-
-        if devtype == "temperature":
-            async_add_entities([HomeKitTemperatureSensor(conn, info)], True)
-            return True
-
-        if devtype == "light":
-            async_add_entities([HomeKitLightSensor(conn, info)], True)
-            return True
-
-        return False
-
-    conn.add_listener(async_add_service)
+UNIT_CO2 = "ppm"
 
 
 class HomeKitHumiditySensor(HomeKitEntity):
@@ -51,9 +25,6 @@ class HomeKitHumiditySensor(HomeKitEntity):
 
     def get_characteristic_types(self):
         """Define the homekit characteristics the entity is tracking."""
-        # pylint: disable=import-error
-        from homekit.model.characteristics import CharacteristicsTypes
-
         return [CharacteristicsTypes.RELATIVE_HUMIDITY_CURRENT]
 
     @property
@@ -90,9 +61,6 @@ class HomeKitTemperatureSensor(HomeKitEntity):
 
     def get_characteristic_types(self):
         """Define the homekit characteristics the entity is tracking."""
-        # pylint: disable=import-error
-        from homekit.model.characteristics import CharacteristicsTypes
-
         return [CharacteristicsTypes.TEMPERATURE_CURRENT]
 
     @property
@@ -129,9 +97,6 @@ class HomeKitLightSensor(HomeKitEntity):
 
     def get_characteristic_types(self):
         """Define the homekit characteristics the entity is tracking."""
-        # pylint: disable=import-error
-        from homekit.model.characteristics import CharacteristicsTypes
-
         return [CharacteristicsTypes.LIGHT_LEVEL_CURRENT]
 
     @property
@@ -156,3 +121,68 @@ class HomeKitLightSensor(HomeKitEntity):
     def state(self):
         """Return the current light level in lux."""
         return self._state
+
+
+class HomeKitCarbonDioxideSensor(HomeKitEntity):
+    """Representation of a Homekit Carbon Dioxide sensor."""
+
+    def __init__(self, *args):
+        """Initialise the entity."""
+        super().__init__(*args)
+        self._state = None
+
+    def get_characteristic_types(self):
+        """Define the homekit characteristics the entity is tracking."""
+        return [CharacteristicsTypes.CARBON_DIOXIDE_LEVEL]
+
+    @property
+    def name(self):
+        """Return the name of the device."""
+        return "{} {}".format(super().name, "CO2")
+
+    @property
+    def icon(self):
+        """Return the sensor icon."""
+        return CO2_ICON
+
+    @property
+    def unit_of_measurement(self):
+        """Return units for the sensor."""
+        return UNIT_CO2
+
+    def _update_carbon_dioxide_level(self, value):
+        self._state = value
+
+    @property
+    def state(self):
+        """Return the current CO2 level in ppm."""
+        return self._state
+
+
+ENTITY_TYPES = {
+    "humidity": HomeKitHumiditySensor,
+    "temperature": HomeKitTemperatureSensor,
+    "light": HomeKitLightSensor,
+    "carbon-dioxide": HomeKitCarbonDioxideSensor,
+}
+
+
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
+    """Legacy set up platform."""
+    pass
+
+
+async def async_setup_entry(hass, config_entry, async_add_entities):
+    """Set up Homekit sensors."""
+    hkid = config_entry.data["AccessoryPairingID"]
+    conn = hass.data[KNOWN_DEVICES][hkid]
+
+    def async_add_service(aid, service):
+        entity_class = ENTITY_TYPES.get(service["stype"])
+        if not entity_class:
+            return False
+        info = {"aid": aid, "iid": service["iid"]}
+        async_add_entities([entity_class(conn, info)], True)
+        return True
+
+    conn.add_listener(async_add_service)
