@@ -9,47 +9,62 @@ import voluptuous as vol
 from homeassistant.helpers.entity import Entity
 from homeassistant.components.sensor import PLATFORM_SCHEMA
 from homeassistant.const import (
-    CONF_NAME, CONF_PORT, CONF_USERNAME, CONF_PASSWORD, CONF_VALUE_TEMPLATE,
-    CONTENT_TYPE_TEXT_PLAIN, ATTR_DATE)
+    CONF_NAME,
+    CONF_PORT,
+    CONF_USERNAME,
+    CONF_PASSWORD,
+    CONF_VALUE_TEMPLATE,
+    CONTENT_TYPE_TEXT_PLAIN,
+    ATTR_DATE,
+)
 import homeassistant.helpers.config_validation as cv
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_SERVER = 'server'
-CONF_SENDERS = 'senders'
-CONF_FOLDER = 'folder'
+CONF_SERVER = "server"
+CONF_SENDERS = "senders"
+CONF_FOLDER = "folder"
 
-ATTR_FROM = 'from'
-ATTR_BODY = 'body'
-ATTR_SUBJECT = 'subject'
+ATTR_FROM = "from"
+ATTR_BODY = "body"
+ATTR_SUBJECT = "subject"
 
 DEFAULT_PORT = 993
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_NAME): cv.string,
-    vol.Required(CONF_USERNAME): cv.string,
-    vol.Required(CONF_PASSWORD): cv.string,
-    vol.Required(CONF_SERVER): cv.string,
-    vol.Required(CONF_SENDERS): [cv.string],
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-    vol.Optional(CONF_VALUE_TEMPLATE): cv.template,
-    vol.Optional(CONF_FOLDER, default='INBOX'): cv.string,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_NAME): cv.string,
+        vol.Required(CONF_USERNAME): cv.string,
+        vol.Required(CONF_PASSWORD): cv.string,
+        vol.Required(CONF_SERVER): cv.string,
+        vol.Required(CONF_SENDERS): [cv.string],
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Optional(CONF_VALUE_TEMPLATE): cv.template,
+        vol.Optional(CONF_FOLDER, default="INBOX"): cv.string,
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Email sensor platform."""
     reader = EmailReader(
-        config.get(CONF_USERNAME), config.get(CONF_PASSWORD),
-        config.get(CONF_SERVER), config.get(CONF_PORT),
-        config.get(CONF_FOLDER))
+        config.get(CONF_USERNAME),
+        config.get(CONF_PASSWORD),
+        config.get(CONF_SERVER),
+        config.get(CONF_PORT),
+        config.get(CONF_FOLDER),
+    )
 
     value_template = config.get(CONF_VALUE_TEMPLATE)
     if value_template is not None:
         value_template.hass = hass
     sensor = EmailContentSensor(
-        hass, reader, config.get(CONF_NAME) or config.get(CONF_USERNAME),
-        config.get(CONF_SENDERS), value_template)
+        hass,
+        reader,
+        config.get(CONF_NAME) or config.get(CONF_USERNAME),
+        config.get(CONF_SENDERS),
+        value_template,
+    )
 
     if sensor.connected:
         add_entities([sensor], True)
@@ -74,6 +89,7 @@ class EmailReader:
     def connect(self):
         """Login and setup the connection."""
         import imaplib
+
         try:
             self.connection = imaplib.IMAP4_SSL(self._server, self._port)
             self.connection.login(self._user, self._password)
@@ -84,8 +100,7 @@ class EmailReader:
 
     def _fetch_message(self, message_uid):
         """Get an email message from a message id."""
-        _, message_data = self.connection.uid(
-            'fetch', message_uid, '(RFC822)')
+        _, message_data = self.connection.uid("fetch", message_uid, "(RFC822)")
 
         if message_data is None:
             return None
@@ -96,6 +111,7 @@ class EmailReader:
     def read_next(self):
         """Read the next email from the email server."""
         import imaplib
+
         try:
             self.connection.select(self._folder, readonly=True)
 
@@ -114,8 +130,7 @@ class EmailReader:
                     return self._fetch_message(message_uid)
 
         except imaplib.IMAP4.error:
-            _LOGGER.info(
-                "Connection to %s lost, attempting to reconnect", self._server)
+            _LOGGER.info("Connection to %s lost, attempting to reconnect", self._server)
             try:
                 self.connect()
             except imaplib.IMAP4.error:
@@ -125,8 +140,7 @@ class EmailReader:
 class EmailContentSensor(Entity):
     """Representation of an EMail sensor."""
 
-    def __init__(self, hass, email_reader, name, allowed_senders,
-                 value_template):
+    def __init__(self, hass, email_reader, name, allowed_senders, value_template):
         """Initialize the sensor."""
         self.hass = hass
         self._email_reader = email_reader
@@ -158,25 +172,26 @@ class EmailContentSensor(Entity):
         variables = {
             ATTR_FROM: EmailContentSensor.get_msg_sender(email_message),
             ATTR_SUBJECT: EmailContentSensor.get_msg_subject(email_message),
-            ATTR_DATE: email_message['Date'],
-            ATTR_BODY: EmailContentSensor.get_msg_text(email_message)
+            ATTR_DATE: email_message["Date"],
+            ATTR_BODY: EmailContentSensor.get_msg_text(email_message),
         }
         return self._value_template.render(variables)
 
     def sender_allowed(self, email_message):
         """Check if the sender is in the allowed senders list."""
         return EmailContentSensor.get_msg_sender(email_message).upper() in (
-            sender for sender in self._allowed_senders)
+            sender for sender in self._allowed_senders
+        )
 
     @staticmethod
     def get_msg_sender(email_message):
         """Get the parsed message sender from the email."""
-        return str(email.utils.parseaddr(email_message['From'])[1])
+        return str(email.utils.parseaddr(email_message["From"])[1])
 
     @staticmethod
     def get_msg_subject(email_message):
         """Decode the message subject."""
-        decoded_header = email.header.decode_header(email_message['Subject'])
+        decoded_header = email.header.decode_header(email_message["Subject"])
         header = email.header.make_header(decoded_header)
         return str(header)
 
@@ -195,10 +210,10 @@ class EmailContentSensor(Entity):
             if part.get_content_type() == CONTENT_TYPE_TEXT_PLAIN:
                 if message_text is None:
                     message_text = part.get_payload()
-            elif part.get_content_type() == 'text/html':
+            elif part.get_content_type() == "text/html":
                 if message_html is None:
                     message_html = part.get_payload()
-            elif part.get_content_type().startswith('text'):
+            elif part.get_content_type().startswith("text"):
                 if message_untyped_text is None:
                     message_untyped_text = part.get_payload()
 
@@ -228,12 +243,8 @@ class EmailContentSensor(Entity):
 
             self._message = message
             self._state_attributes = {
-                ATTR_FROM:
-                    EmailContentSensor.get_msg_sender(email_message),
-                ATTR_SUBJECT:
-                    EmailContentSensor.get_msg_subject(email_message),
-                ATTR_DATE:
-                    email_message['Date'],
-                ATTR_BODY:
-                    EmailContentSensor.get_msg_text(email_message)
+                ATTR_FROM: EmailContentSensor.get_msg_sender(email_message),
+                ATTR_SUBJECT: EmailContentSensor.get_msg_subject(email_message),
+                ATTR_DATE: email_message["Date"],
+                ATTR_BODY: EmailContentSensor.get_msg_text(email_message),
             }
