@@ -2,7 +2,7 @@
 from collections import OrderedDict
 import logging
 
-from life360 import LoginError
+from life360 import Life360Error, LoginError
 import voluptuous as vol
 
 from homeassistant import config_entries
@@ -54,6 +54,11 @@ class Life360ConfigFlow(config_entries.ConfigFlow):
                 errors[CONF_USERNAME] = "invalid_username"
             except LoginError:
                 errors["base"] = "invalid_credentials"
+            except Life360Error as error:
+                _LOGGER.error(
+                    "Unexpected error communicating with Life360 server: %s", error
+                )
+                errors["base"] = "unexpected"
             else:
                 if self._username in self.configured_usernames:
                     errors["base"] = "user_already_configured"
@@ -88,6 +93,11 @@ class Life360ConfigFlow(config_entries.ConfigFlow):
         except LoginError:
             _LOGGER.error("Invalid credentials for %s", username)
             return self.async_abort(reason="invalid_credentials")
+        except Life360Error as error:
+            _LOGGER.error(
+                "Unexpected error communicating with Life360 server: %s", error
+            )
+            return self.async_abort(reason="unexpected")
         return self.async_create_entry(
             title="{} (from configuration)".format(username),
             data={
