@@ -5,10 +5,18 @@ import voluptuous as vol
 
 from homeassistant.components import binary_sensor, mqtt
 from homeassistant.components.binary_sensor import (
-    DEVICE_CLASSES_SCHEMA, BinarySensorDevice)
+    DEVICE_CLASSES_SCHEMA,
+    BinarySensorDevice,
+)
 from homeassistant.const import (
-    CONF_DEVICE, CONF_DEVICE_CLASS, CONF_FORCE_UPDATE, CONF_NAME,
-    CONF_PAYLOAD_OFF, CONF_PAYLOAD_ON, CONF_VALUE_TEMPLATE)
+    CONF_DEVICE,
+    CONF_DEVICE_CLASS,
+    CONF_FORCE_UPDATE,
+    CONF_NAME,
+    CONF_PAYLOAD_OFF,
+    CONF_PAYLOAD_ON,
+    CONF_VALUE_TEMPLATE,
+)
 from homeassistant.core import callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -16,67 +24,86 @@ import homeassistant.helpers.event as evt
 from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 
 from . import (
-    ATTR_DISCOVERY_HASH, CONF_QOS, CONF_STATE_TOPIC, CONF_UNIQUE_ID,
-    MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
-    MqttEntityDeviceInfo, subscription)
+    ATTR_DISCOVERY_HASH,
+    CONF_QOS,
+    CONF_STATE_TOPIC,
+    CONF_UNIQUE_ID,
+    MqttAttributes,
+    MqttAvailability,
+    MqttDiscoveryUpdate,
+    MqttEntityDeviceInfo,
+    subscription,
+)
 from .discovery import MQTT_DISCOVERY_NEW, clear_discovery_hash
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_NAME = 'MQTT Binary sensor'
-CONF_OFF_DELAY = 'off_delay'
-DEFAULT_PAYLOAD_OFF = 'OFF'
-DEFAULT_PAYLOAD_ON = 'ON'
+DEFAULT_NAME = "MQTT Binary sensor"
+CONF_OFF_DELAY = "off_delay"
+DEFAULT_PAYLOAD_OFF = "OFF"
+DEFAULT_PAYLOAD_ON = "ON"
 DEFAULT_FORCE_UPDATE = False
 
-PLATFORM_SCHEMA = mqtt.MQTT_RO_PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_DEVICE): mqtt.MQTT_ENTITY_DEVICE_INFO_SCHEMA,
-    vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
-    vol.Optional(CONF_FORCE_UPDATE, default=DEFAULT_FORCE_UPDATE): cv.boolean,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_OFF_DELAY):
-        vol.All(vol.Coerce(int), vol.Range(min=0)),
-    vol.Optional(CONF_PAYLOAD_OFF, default=DEFAULT_PAYLOAD_OFF): cv.string,
-    vol.Optional(CONF_PAYLOAD_ON, default=DEFAULT_PAYLOAD_ON): cv.string,
-    vol.Optional(CONF_UNIQUE_ID): cv.string,
-}).extend(mqtt.MQTT_AVAILABILITY_SCHEMA.schema).extend(
-    mqtt.MQTT_JSON_ATTRS_SCHEMA.schema)
+PLATFORM_SCHEMA = (
+    mqtt.MQTT_RO_PLATFORM_SCHEMA.extend(
+        {
+            vol.Optional(CONF_DEVICE): mqtt.MQTT_ENTITY_DEVICE_INFO_SCHEMA,
+            vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
+            vol.Optional(CONF_FORCE_UPDATE, default=DEFAULT_FORCE_UPDATE): cv.boolean,
+            vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+            vol.Optional(CONF_OFF_DELAY): vol.All(vol.Coerce(int), vol.Range(min=0)),
+            vol.Optional(CONF_PAYLOAD_OFF, default=DEFAULT_PAYLOAD_OFF): cv.string,
+            vol.Optional(CONF_PAYLOAD_ON, default=DEFAULT_PAYLOAD_ON): cv.string,
+            vol.Optional(CONF_UNIQUE_ID): cv.string,
+        }
+    )
+    .extend(mqtt.MQTT_AVAILABILITY_SCHEMA.schema)
+    .extend(mqtt.MQTT_JSON_ATTRS_SCHEMA.schema)
+)
 
 
-async def async_setup_platform(hass: HomeAssistantType, config: ConfigType,
-                               async_add_entities, discovery_info=None):
+async def async_setup_platform(
+    hass: HomeAssistantType, config: ConfigType, async_add_entities, discovery_info=None
+):
     """Set up MQTT binary sensor through configuration.yaml."""
     await _async_setup_entity(config, async_add_entities)
 
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up MQTT binary sensor dynamically through MQTT discovery."""
+
     async def async_discover(discovery_payload):
         """Discover and add a MQTT binary sensor."""
         try:
             discovery_hash = discovery_payload.pop(ATTR_DISCOVERY_HASH)
             config = PLATFORM_SCHEMA(discovery_payload)
-            await _async_setup_entity(config, async_add_entities, config_entry,
-                                      discovery_hash)
+            await _async_setup_entity(
+                config, async_add_entities, config_entry, discovery_hash
+            )
         except Exception:
             if discovery_hash:
                 clear_discovery_hash(hass, discovery_hash)
             raise
 
     async_dispatcher_connect(
-        hass, MQTT_DISCOVERY_NEW.format(binary_sensor.DOMAIN, 'mqtt'),
-        async_discover)
+        hass, MQTT_DISCOVERY_NEW.format(binary_sensor.DOMAIN, "mqtt"), async_discover
+    )
 
 
-async def _async_setup_entity(config, async_add_entities, config_entry=None,
-                              discovery_hash=None):
+async def _async_setup_entity(
+    config, async_add_entities, config_entry=None, discovery_hash=None
+):
     """Set up the MQTT binary sensor."""
-    async_add_entities([MqttBinarySensor(config, config_entry,
-                                         discovery_hash)])
+    async_add_entities([MqttBinarySensor(config, config_entry, discovery_hash)])
 
 
-class MqttBinarySensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
-                       MqttEntityDeviceInfo, BinarySensorDevice):
+class MqttBinarySensor(
+    MqttAttributes,
+    MqttAvailability,
+    MqttDiscoveryUpdate,
+    MqttEntityDeviceInfo,
+    BinarySensorDevice,
+):
     """Representation a binary sensor that is updated by MQTT."""
 
     def __init__(self, config, config_entry, discovery_hash):
@@ -91,8 +118,7 @@ class MqttBinarySensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
 
         MqttAttributes.__init__(self, config)
         MqttAvailability.__init__(self, config)
-        MqttDiscoveryUpdate.__init__(self, discovery_hash,
-                                     self.discovery_update)
+        MqttDiscoveryUpdate.__init__(self, discovery_hash, self.discovery_update)
         MqttEntityDeviceInfo.__init__(self, device_config, config_entry)
 
     async def async_added_to_hass(self):
@@ -130,16 +156,18 @@ class MqttBinarySensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
             value_template = self._config.get(CONF_VALUE_TEMPLATE)
             if value_template is not None:
                 payload = value_template.async_render_with_possible_json_value(
-                    payload, variables={'entity_id': self.entity_id})
+                    payload, variables={"entity_id": self.entity_id}
+                )
             if payload == self._config[CONF_PAYLOAD_ON]:
                 self._state = True
             elif payload == self._config[CONF_PAYLOAD_OFF]:
                 self._state = False
             else:  # Payload is not for this entity
-                _LOGGER.warning('No matching payload found'
-                                ' for entity: %s with state_topic: %s',
-                                self._config[CONF_NAME],
-                                self._config[CONF_STATE_TOPIC])
+                _LOGGER.warning(
+                    "No matching payload found" " for entity: %s with state_topic: %s",
+                    self._config[CONF_NAME],
+                    self._config[CONF_STATE_TOPIC],
+                )
                 return
 
             if self._delay_listener is not None:
@@ -147,22 +175,30 @@ class MqttBinarySensor(MqttAttributes, MqttAvailability, MqttDiscoveryUpdate,
                 self._delay_listener = None
 
             off_delay = self._config.get(CONF_OFF_DELAY)
-            if (self._state and off_delay is not None):
+            if self._state and off_delay is not None:
                 self._delay_listener = evt.async_call_later(
-                    self.hass, off_delay, off_delay_listener)
+                    self.hass, off_delay, off_delay_listener
+                )
 
             self.async_write_ha_state()
 
         self._sub_state = await subscription.async_subscribe_topics(
-            self.hass, self._sub_state,
-            {'state_topic': {'topic': self._config[CONF_STATE_TOPIC],
-                             'msg_callback': state_message_received,
-                             'qos': self._config[CONF_QOS]}})
+            self.hass,
+            self._sub_state,
+            {
+                "state_topic": {
+                    "topic": self._config[CONF_STATE_TOPIC],
+                    "msg_callback": state_message_received,
+                    "qos": self._config[CONF_QOS],
+                }
+            },
+        )
 
     async def async_will_remove_from_hass(self):
         """Unsubscribe when removed."""
         self._sub_state = await subscription.async_unsubscribe_topics(
-            self.hass, self._sub_state)
+            self.hass, self._sub_state
+        )
         await MqttAttributes.async_will_remove_from_hass(self)
         await MqttAvailability.async_will_remove_from_hass(self)
 
