@@ -13,27 +13,41 @@ from homeassistant.util import Throttle
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_STATION_ID = 'station_id'
-ATTR_STATION_NAME = 'station_name'
+ATTR_STATION_ID = "station_id"
+ATTR_STATION_NAME = "station_name"
 
-CONF_STATION_ID = 'station_id'
-CONF_FUEL_TYPES = 'fuel_types'
-CONF_ALLOWED_FUEL_TYPES = ["E10", "U91", "E85", "P95", "P98", "DL",
-                           "PDL", "B20", "LPG", "CNG", "EV"]
+CONF_STATION_ID = "station_id"
+CONF_FUEL_TYPES = "fuel_types"
+CONF_ALLOWED_FUEL_TYPES = [
+    "E10",
+    "U91",
+    "E85",
+    "P95",
+    "P98",
+    "DL",
+    "PDL",
+    "B20",
+    "LPG",
+    "CNG",
+    "EV",
+]
 CONF_DEFAULT_FUEL_TYPES = ["E10", "U91"]
 
 ATTRIBUTION = "Data provided by NSW Government FuelCheck"
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_STATION_ID): cv.positive_int,
-    vol.Optional(CONF_FUEL_TYPES, default=CONF_DEFAULT_FUEL_TYPES):
-        vol.All(cv.ensure_list, [vol.In(CONF_ALLOWED_FUEL_TYPES)]),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_STATION_ID): cv.positive_int,
+        vol.Optional(CONF_FUEL_TYPES, default=CONF_DEFAULT_FUEL_TYPES): vol.All(
+            cv.ensure_list, [vol.In(CONF_ALLOWED_FUEL_TYPES)]
+        ),
+    }
+)
 
 MIN_TIME_BETWEEN_UPDATES = datetime.timedelta(hours=1)
 
-NOTIFICATION_ID = 'nsw_fuel_station_notification'
-NOTIFICATION_TITLE = 'NSW Fuel Station Sensor Setup'
+NOTIFICATION_ID = "nsw_fuel_station_notification"
+NOTIFICATION_TITLE = "NSW Fuel Station Sensor Setup"
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -48,23 +62,24 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     station_data.update()
 
     if station_data.error is not None:
-        message = (
-            'Error: {}. Check the logs for additional information.'
-        ).format(station_data.error)
+        message = ("Error: {}. Check the logs for additional information.").format(
+            station_data.error
+        )
 
         hass.components.persistent_notification.create(
-            message,
-            title=NOTIFICATION_TITLE,
-            notification_id=NOTIFICATION_ID)
+            message, title=NOTIFICATION_TITLE, notification_id=NOTIFICATION_ID
+        )
         return
 
     available_fuel_types = station_data.get_available_fuel_types()
 
-    add_entities([
-        StationPriceSensor(station_data, fuel_type)
-        for fuel_type in fuel_types
-        if fuel_type in available_fuel_types
-    ])
+    add_entities(
+        [
+            StationPriceSensor(station_data, fuel_type)
+            for fuel_type in fuel_types
+            if fuel_type in available_fuel_types
+        ]
+    )
 
 
 class StationPriceData:
@@ -90,23 +105,23 @@ class StationPriceData:
             except FuelCheckError as exc:
                 self.error = str(exc)
                 _LOGGER.error(
-                    'Failed to fetch NSW Fuel station reference data. %s', exc)
+                    "Failed to fetch NSW Fuel station reference data. %s", exc
+                )
                 return
 
         try:
-            self._data = self._client.get_fuel_prices_for_station(
-                self.station_id)
+            self._data = self._client.get_fuel_prices_for_station(self.station_id)
         except FuelCheckError as exc:
             self.error = str(exc)
-            _LOGGER.error(
-                'Failed to fetch NSW Fuel station price data. %s', exc)
+            _LOGGER.error("Failed to fetch NSW Fuel station price data. %s", exc)
 
     def for_fuel_type(self, fuel_type: str):
         """Return the price of the given fuel type."""
         if self._data is None:
             return None
-        return next((price for price
-                     in self._data if price.fuel_type == fuel_type), None)
+        return next(
+            (price for price in self._data if price.fuel_type == fuel_type), None
+        )
 
     def get_available_fuel_types(self):
         """Return the available fuel types for the station."""
@@ -117,11 +132,16 @@ class StationPriceData:
         if self._station_name is None:
             name = None
             if self._reference_data is not None:
-                name = next((station.name for station
-                             in self._reference_data.stations
-                             if station.code == self.station_id), None)
+                name = next(
+                    (
+                        station.name
+                        for station in self._reference_data.stations
+                        if station.code == self.station_id
+                    ),
+                    None,
+                )
 
-            self._station_name = name or 'station {}'.format(self.station_id)
+            self._station_name = name or "station {}".format(self.station_id)
 
         return self._station_name
 
@@ -137,8 +157,7 @@ class StationPriceSensor(Entity):
     @property
     def name(self) -> str:
         """Return the name of the sensor."""
-        return '{} {}'.format(
-            self._station_data.get_station_name(), self._fuel_type)
+        return "{} {}".format(self._station_data.get_station_name(), self._fuel_type)
 
     @property
     def state(self) -> Optional[float]:
@@ -155,13 +174,13 @@ class StationPriceSensor(Entity):
         return {
             ATTR_STATION_ID: self._station_data.station_id,
             ATTR_STATION_NAME: self._station_data.get_station_name(),
-            ATTR_ATTRIBUTION: ATTRIBUTION
+            ATTR_ATTRIBUTION: ATTRIBUTION,
         }
 
     @property
     def unit_of_measurement(self) -> str:
         """Return the units of measurement."""
-        return '¢/L'
+        return "¢/L"
 
     def update(self):
         """Update current conditions."""
