@@ -30,6 +30,7 @@ from .const import (
     ATTR_GW_ID,
     ATTR_MODE,
     ATTR_LEVEL,
+    ATTR_DHW_OVRD,
     CONF_CLIMATE,
     CONF_FLOOR_TEMP,
     CONF_PRECISION,
@@ -38,6 +39,7 @@ from .const import (
     SERVICE_RESET_GATEWAY,
     SERVICE_SET_CLOCK,
     SERVICE_SET_CONTROL_SETPOINT,
+    SERVICE_SET_HOT_WATER_OVRD,
     SERVICE_SET_GPIO_MODE,
     SERVICE_SET_LED_MODE,
     SERVICE_SET_MAX_MOD,
@@ -123,6 +125,16 @@ def register_services(hass):
             ),
         }
     )
+    service_set_hot_water_ovrd_schema = vol.Schema(
+        {
+            vol.Required(ATTR_GW_ID): vol.All(
+                cv.string, vol.In(hass.data[DATA_OPENTHERM_GW][DATA_GATEWAYS])
+            ),
+            vol.Required(ATTR_DHW_OVRD): vol.Any(
+                vol.Equal("A"), vol.All(vol.Coerce(int), vol.Range(min=0, max=1))
+            ),
+        }
+    )
     service_set_gpio_mode_schema = vol.Schema(
         vol.Any(
             vol.Schema(
@@ -216,6 +228,21 @@ def register_services(hass):
         service_set_control_setpoint_schema,
     )
 
+    async def set_dhw_ovrd(call):
+        """Set the domestic hot water override on the OpenTherm Gateway."""
+        gw_dev = hass.data[DATA_OPENTHERM_GW][DATA_GATEWAYS][call.data[ATTR_GW_ID]]
+        gw_var = gw_vars.OTGW_DHW_OVRD
+        value = await gw_dev.gateway.set_hot_water_ovrd(call.data[ATTR_DHW_OVRD])
+        gw_dev.status.update({gw_var: value})
+        async_dispatcher_send(hass, gw_dev.update_signal, gw_dev.status)
+
+    hass.services.async_register(
+        DOMAIN,
+        SERVICE_SET_HOT_WATER_OVRD,
+        set_dhw_ovrd,
+        service_set_hot_water_ovrd_schema,
+    )
+
     async def set_device_clock(call):
         """Set the clock on the OpenTherm Gateway."""
         gw_dev = hass.data[DATA_OPENTHERM_GW][DATA_GATEWAYS][call.data[ATTR_GW_ID]]
