@@ -5,14 +5,12 @@ from homeassistant.helpers import config_validation as cv
 
 from . import CONF_PIN_MODE, PIN_MODES
 
-CONF_INVERT_LOGIC = 'invert_logic'
-CONF_PORTS = 'ports'
+CONF_INVERT_LOGIC = "invert_logic"
+CONF_PORTS = "ports"
 
 DEFAULT_INVERT_LOGIC = False
 
-_SENSORS_SCHEMA = vol.Schema({
-    cv.positive_int: cv.string,
-})
+_SENSORS_SCHEMA = vol.Schema({cv.positive_int: cv.string})
 
 PORT_SCHEMA = {
     vol.Required(CONF_PORTS): _SENSORS_SCHEMA,
