@@ -4,30 +4,27 @@ from threading import Lock
 
 import voluptuous as vol
 
-from homeassistant.const import (CONF_DEVICE, CONF_NAME)
+from homeassistant.const import CONF_DEVICE, CONF_NAME
 from homeassistant.core import EVENT_HOMEASSISTANT_STOP
 import homeassistant.helpers.config_validation as cv
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_STATE = 'state'
+ATTR_STATE = "state"
 
-CONF_SCS_ID = 'scs_id'
+CONF_SCS_ID = "scs_id"
 
-DOMAIN = 'scsgate'
+DOMAIN = "scsgate"
 
 SCSGATE = None
 
-CONFIG_SCHEMA = vol.Schema({
-    DOMAIN: vol.Schema({
-        vol.Required(CONF_DEVICE): cv.string,
-    }),
-}, extra=vol.ALLOW_EXTRA)
+CONFIG_SCHEMA = vol.Schema(
+    {DOMAIN: vol.Schema({vol.Required(CONF_DEVICE): cv.string})}, extra=vol.ALLOW_EXTRA
+)
 
-SCSGATE_SCHEMA = vol.Schema({
-    vol.Required(CONF_SCS_ID): cv.string,
-    vol.Optional(CONF_NAME): cv.string,
-})
+SCSGATE_SCHEMA = vol.Schema(
+    {vol.Required(CONF_SCS_ID): cv.string, vol.Optional(CONF_NAME): cv.string}
+)
 
 
 def setup(hass, config):
@@ -65,22 +62,26 @@ class SCSGate:
         self._device_being_registered_lock = Lock()
 
         from scsgate.connection import Connection
+
         connection = Connection(device=device, logger=self._logger)
 
         from scsgate.reactor import Reactor
+
         self._reactor = Reactor(
-            connection=connection, logger=self._logger,
-            handle_message=self.handle_message)
+            connection=connection,
+            logger=self._logger,
+            handle_message=self.handle_message,
+        )
 
     def handle_message(self, message):
         """Handle a messages seen on the bus."""
         from scsgate.messages import StateMessage, ScenarioTriggeredMessage
 
         self._logger.debug("Received message {}".format(message))
-        if not isinstance(message, StateMessage) and \
-           not isinstance(message, ScenarioTriggeredMessage):
-            msg = "Ignored message {} - not relevant type".format(
-                message)
+        if not isinstance(message, StateMessage) and not isinstance(
+            message, ScenarioTriggeredMessage
+        ):
+            msg = "Ignored message {} - not relevant type".format(message)
             self._logger.debug(msg)
             return
 
@@ -101,7 +102,9 @@ class SCSGate:
         else:
             self._logger.info(
                 "Ignoring state message for device {} because unknown".format(
-                    message.entity))
+                    message.entity
+                )
+            )
 
     @property
     def devices(self):
