@@ -10,12 +10,26 @@ import pysensibo
 
 from homeassistant.components.climate import PLATFORM_SCHEMA, ClimateDevice
 from homeassistant.components.climate.const import (
-    HVAC_MODE_HEAT_COOL, HVAC_MODE_COOL, HVAC_MODE_DRY,
-    HVAC_MODE_FAN_ONLY, HVAC_MODE_HEAT, HVAC_MODE_OFF, SUPPORT_FAN_MODE,
-    SUPPORT_SWING_MODE, SUPPORT_TARGET_TEMPERATURE)
+    HVAC_MODE_HEAT_COOL,
+    HVAC_MODE_COOL,
+    HVAC_MODE_DRY,
+    HVAC_MODE_FAN_ONLY,
+    HVAC_MODE_HEAT,
+    HVAC_MODE_OFF,
+    SUPPORT_FAN_MODE,
+    SUPPORT_SWING_MODE,
+    SUPPORT_TARGET_TEMPERATURE,
+)
 from homeassistant.const import (
-    ATTR_ENTITY_ID, ATTR_STATE, ATTR_TEMPERATURE, CONF_API_KEY, CONF_ID,
-    STATE_ON, TEMP_CELSIUS, TEMP_FAHRENHEIT)
+    ATTR_ENTITY_ID,
+    ATTR_STATE,
+    ATTR_TEMPERATURE,
+    CONF_API_KEY,
+    CONF_ID,
+    STATE_ON,
+    TEMP_CELSIUS,
+    TEMP_FAHRENHEIT,
+)
 from homeassistant.exceptions import PlatformNotReady
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
@@ -25,30 +39,38 @@ from .const import DOMAIN as SENSIBO_DOMAIN
 
 _LOGGER = logging.getLogger(__name__)
 
-ALL = ['all']
+ALL = ["all"]
 TIMEOUT = 10
 
-SERVICE_ASSUME_STATE = 'assume_state'
+SERVICE_ASSUME_STATE = "assume_state"
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_API_KEY): cv.string,
-    vol.Optional(CONF_ID, default=ALL): vol.All(cv.ensure_list, [cv.string]),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_API_KEY): cv.string,
+        vol.Optional(CONF_ID, default=ALL): vol.All(cv.ensure_list, [cv.string]),
+    }
+)
 
-ASSUME_STATE_SCHEMA = vol.Schema({
-    vol.Optional(ATTR_ENTITY_ID): cv.entity_ids,
-    vol.Required(ATTR_STATE): cv.string,
-})
+ASSUME_STATE_SCHEMA = vol.Schema(
+    {vol.Optional(ATTR_ENTITY_ID): cv.entity_ids, vol.Required(ATTR_STATE): cv.string}
+)
 
-_FETCH_FIELDS = ','.join([
-    'room{name}', 'measurements', 'remoteCapabilities',
-    'acState', 'connectionStatus{isAlive}', 'temperatureUnit'])
-_INITIAL_FETCH_FIELDS = 'id,' + _FETCH_FIELDS
+_FETCH_FIELDS = ",".join(
+    [
+        "room{name}",
+        "measurements",
+        "remoteCapabilities",
+        "acState",
+        "connectionStatus{isAlive}",
+        "temperatureUnit",
+    ]
+)
+_INITIAL_FETCH_FIELDS = "id," + _FETCH_FIELDS
 
 FIELD_TO_FLAG = {
-    'fanLevel':  SUPPORT_FAN_MODE,
-    'swing': SUPPORT_SWING_MODE,
-    'targetTemperature': SUPPORT_TARGET_TEMPERATURE,
+    "fanLevel": SUPPORT_FAN_MODE,
+    "swing": SUPPORT_SWING_MODE,
+    "targetTemperature": SUPPORT_TARGET_TEMPERATURE,
 }
 
 SENSIBO_TO_HA = {
@@ -56,28 +78,30 @@ SENSIBO_TO_HA = {
     "heat": HVAC_MODE_HEAT,
     "fan": HVAC_MODE_FAN_ONLY,
     "auto": HVAC_MODE_HEAT_COOL,
-    "dry": HVAC_MODE_DRY
+    "dry": HVAC_MODE_DRY,
 }
 
 HA_TO_SENSIBO = {value: key for key, value in SENSIBO_TO_HA.items()}
 
 
-async def async_setup_platform(hass, config, async_add_entities,
-                               discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up Sensibo devices."""
     client = pysensibo.SensiboClient(
-        config[CONF_API_KEY], session=async_get_clientsession(hass),
-        timeout=TIMEOUT)
+        config[CONF_API_KEY], session=async_get_clientsession(hass), timeout=TIMEOUT
+    )
     devices = []
     try:
-        for dev in (
-                await client.async_get_devices(_INITIAL_FETCH_FIELDS)):
-            if config[CONF_ID] == ALL or dev['id'] in config[CONF_ID]:
-                devices.append(SensiboClimate(
-                    client, dev, hass.config.units.temperature_unit))
-    except (aiohttp.client_exceptions.ClientConnectorError,
-            asyncio.TimeoutError, pysensibo.SensiboError):
-        _LOGGER.exception('Failed to connect to Sensibo servers.')
+        for dev in await client.async_get_devices(_INITIAL_FETCH_FIELDS):
+            if config[CONF_ID] == ALL or dev["id"] in config[CONF_ID]:
+                devices.append(
+                    SensiboClimate(client, dev, hass.config.units.temperature_unit)
+                )
+    except (
+        aiohttp.client_exceptions.ClientConnectorError,
+        asyncio.TimeoutError,
+        pysensibo.SensiboError,
+    ):
+        _LOGGER.exception("Failed to connect to Sensibo servers.")
         raise PlatformNotReady
 
     if not devices:
@@ -89,23 +113,26 @@ async def async_setup_platform(hass, config, async_add_entities,
         """Set state according to external service call.."""
         entity_ids = service.data.get(ATTR_ENTITY_ID)
         if entity_ids:
-            target_climate = [device for device in devices
-                              if device.entity_id in entity_ids]
+            target_climate = [
+                device for device in devices if device.entity_id in entity_ids
+            ]
         else:
             target_climate = devices
 
         update_tasks = []
         for climate in target_climate:
-            await climate.async_assume_state(
-                service.data.get(ATTR_STATE))
+            await climate.async_assume_state(service.data.get(ATTR_STATE))
             update_tasks.append(climate.async_update_ha_state(True))
 
         if update_tasks:
             await asyncio.wait(update_tasks)
 
     hass.services.async_register(
-        SENSIBO_DOMAIN, SERVICE_ASSUME_STATE, async_assume_state,
-        schema=ASSUME_STATE_SCHEMA)
+        SENSIBO_DOMAIN,
+        SERVICE_ASSUME_STATE,
+        async_assume_state,
+        schema=ASSUME_STATE_SCHEMA,
+    )
 
 
 class SensiboClimate(ClimateDevice):
@@ -118,7 +145,7 @@ class SensiboClimate(ClimateDevice):
         data: initially-fetched data.
         """
         self._client = client
-        self._id = data['id']
+        self._id = data["id"]
         self._external_state = None
         self._units = units
         self._available = False
@@ -130,23 +157,26 @@ class SensiboClimate(ClimateDevice):
         return self._supported_features
 
     def _do_update(self, data):
-        self._name = data['room']['name']
-        self._measurements = data['measurements']
-        self._ac_states = data['acState']
-        self._available = data['connectionStatus']['isAlive']
-        capabilities = data['remoteCapabilities']
-        self._operations = [SENSIBO_TO_HA[mode] for mode
-                            in capabilities['modes']]
+        self._name = data["room"]["name"]
+        self._measurements = data["measurements"]
+        self._ac_states = data["acState"]
+        self._available = data["connectionStatus"]["isAlive"]
+        capabilities = data["remoteCapabilities"]
+        self._operations = [SENSIBO_TO_HA[mode] for mode in capabilities["modes"]]
         self._operations.append(HVAC_MODE_OFF)
-        self._current_capabilities = \
-            capabilities['modes'][self._ac_states['mode']]
-        temperature_unit_key = data.get('temperatureUnit') or \
-            self._ac_states.get('temperatureUnit')
+        self._current_capabilities = capabilities["modes"][self._ac_states["mode"]]
+        temperature_unit_key = data.get("temperatureUnit") or self._ac_states.get(
+            "temperatureUnit"
+        )
         if temperature_unit_key:
-            self._temperature_unit = TEMP_CELSIUS if \
-                temperature_unit_key == 'C' else TEMP_FAHRENHEIT
-            self._temperatures_list = self._current_capabilities[
-                'temperatures'].get(temperature_unit_key, {}).get('values', [])
+            self._temperature_unit = (
+                TEMP_CELSIUS if temperature_unit_key == "C" else TEMP_FAHRENHEIT
+            )
+            self._temperatures_list = (
+                self._current_capabilities["temperatures"]
+                .get(temperature_unit_key, {})
+                .get("values", [])
+            )
         else:
             self._temperature_unit = self._units
             self._temperatures_list = []
@@ -163,7 +193,7 @@ class SensiboClimate(ClimateDevice):
     @property
     def device_state_attributes(self):
         """Return the state attributes."""
-        return {'battery': self.current_battery}
+        return {"battery": self.current_battery}
 
     @property
     def temperature_unit(self):
@@ -178,7 +208,7 @@ class SensiboClimate(ClimateDevice):
     @property
     def target_temperature(self):
         """Return the temperature we try to reach."""
-        return self._ac_states.get('targetTemperature')
+        return self._ac_states.get("targetTemperature")
 
     @property
     def target_temperature_step(self):
@@ -193,19 +223,19 @@ class SensiboClimate(ClimateDevice):
     @property
     def hvac_mode(self):
         """Return current operation ie. heat, cool, idle."""
-        if not self._ac_states['on']:
+        if not self._ac_states["on"]:
             return HVAC_MODE_OFF
-        return SENSIBO_TO_HA.get(self._ac_states['mode'])
+        return SENSIBO_TO_HA.get(self._ac_states["mode"])
 
     @property
     def current_humidity(self):
         """Return the current humidity."""
-        return self._measurements['humidity']
+        return self._measurements["humidity"]
 
     @property
     def current_battery(self):
         """Return the current battery voltage."""
-        return self._measurements.get('batteryVoltage')
+        return self._measurements.get("batteryVoltage")
 
     @property
     def current_temperature(self):
@@ -213,9 +243,8 @@ class SensiboClimate(ClimateDevice):
         # This field is not affected by temperatureUnit.
         # It is always in C
         return convert_temperature(
-            self._measurements['temperature'],
-            TEMP_CELSIUS,
-            self.temperature_unit)
+            self._measurements["temperature"], TEMP_CELSIUS, self.temperature_unit
+        )
 
     @property
     def hvac_modes(self):
@@ -225,22 +254,22 @@ class SensiboClimate(ClimateDevice):
     @property
     def fan_mode(self):
         """Return the fan setting."""
-        return self._ac_states.get('fanLevel')
+        return self._ac_states.get("fanLevel")
 
     @property
     def fan_modes(self):
         """List of available fan modes."""
-        return self._current_capabilities.get('fanLevels')
+        return self._current_capabilities.get("fanLevels")
 
     @property
     def swing_mode(self):
         """Return the fan setting."""
-        return self._ac_states.get('swing')
+        return self._ac_states.get("swing")
 
     @property
     def swing_modes(self):
         """List of available swing modes."""
-        return self._current_capabilities.get('swing')
+        return self._current_capabilities.get("swing")
 
     @property
     def name(self):
@@ -250,14 +279,16 @@ class SensiboClimate(ClimateDevice):
     @property
     def min_temp(self):
         """Return the minimum temperature."""
-        return self._temperatures_list[0] \
-            if self._temperatures_list else super().min_temp
+        return (
+            self._temperatures_list[0] if self._temperatures_list else super().min_temp
+        )
 
     @property
     def max_temp(self):
         """Return the maximum temperature."""
-        return self._temperatures_list[-1] \
-            if self._temperatures_list else super().max_temp
+        return (
+            self._temperatures_list[-1] if self._temperatures_list else super().max_temp
+        )
 
     @property
     def unique_id(self):
@@ -275,8 +306,10 @@ class SensiboClimate(ClimateDevice):
             if temperature == self.target_temperature:
                 return
             index = self._temperatures_list.index(self.target_temperature)
-            if temperature > self.target_temperature and index < len(
-                    self._temperatures_list) - 1:
+            if (
+                temperature > self.target_temperature
+                and index < len(self._temperatures_list) - 1
+            ):
                 temperature = self._temperatures_list[index + 1]
             elif temperature < self.target_temperature and index > 0:
                 temperature = self._temperatures_list[index - 1]
@@ -285,65 +318,72 @@ class SensiboClimate(ClimateDevice):
 
         with async_timeout.timeout(TIMEOUT):
             await self._client.async_set_ac_state_property(
-                self._id, 'targetTemperature', temperature, self._ac_states)
+                self._id, "targetTemperature", temperature, self._ac_states
+            )
 
     async def async_set_fan_mode(self, fan_mode):
         """Set new target fan mode."""
         with async_timeout.timeout(TIMEOUT):
             await self._client.async_set_ac_state_property(
-                self._id, 'fanLevel', fan_mode, self._ac_states)
+                self._id, "fanLevel", fan_mode, self._ac_states
+            )
 
     async def async_set_hvac_mode(self, hvac_mode):
         """Set new target operation mode."""
         if hvac_mode == HVAC_MODE_OFF:
             with async_timeout.timeout(TIMEOUT):
                 await self._client.async_set_ac_state_property(
-                    self._id, 'on', False, self._ac_states)
+                    self._id, "on", False, self._ac_states
+                )
             return
 
         # Turn on if not currently on.
-        if not self._ac_states['on']:
+        if not self._ac_states["on"]:
             with async_timeout.timeout(TIMEOUT):
                 await self._client.async_set_ac_state_property(
-                    self._id, 'on', True, self._ac_states)
+                    self._id, "on", True, self._ac_states
+                )
 
         with async_timeout.timeout(TIMEOUT):
             await self._client.async_set_ac_state_property(
-                self._id, 'mode', HA_TO_SENSIBO[hvac_mode],
-                self._ac_states)
+                self._id, "mode", HA_TO_SENSIBO[hvac_mode], self._ac_states
+            )
 
     async def async_set_swing_mode(self, swing_mode):
         """Set new target swing operation."""
         with async_timeout.timeout(TIMEOUT):
             await self._client.async_set_ac_state_property(
-                self._id, 'swing', swing_mode, self._ac_states)
+                self._id, "swing", swing_mode, self._ac_states
+            )
 
     async def async_turn_on(self):
         """Turn Sensibo unit on."""
         with async_timeout.timeout(TIMEOUT):
             await self._client.async_set_ac_state_property(
-                self._id, 'on', True, self._ac_states)
+                self._id, "on", True, self._ac_states
+            )
 
     async def async_turn_off(self):
         """Turn Sensibo unit on."""
         with async_timeout.timeout(TIMEOUT):
             await self._client.async_set_ac_state_property(
-                self._id, 'on', False, self._ac_states)
+                self._id, "on", False, self._ac_states
+            )
 
     async def async_assume_state(self, state):
         """Set external state."""
-        change_needed = \
-            (state != HVAC_MODE_OFF and not self._ac_states['on']) \
-            or (state == HVAC_MODE_OFF and self._ac_states['on'])
+        change_needed = (state != HVAC_MODE_OFF and not self._ac_states["on"]) or (
+            state == HVAC_MODE_OFF and self._ac_states["on"]
+        )
 
         if change_needed:
             with async_timeout.timeout(TIMEOUT):
                 await self._client.async_set_ac_state_property(
                     self._id,
-                    'on',
+                    "on",
                     state != HVAC_MODE_OFF,  # value
                     self._ac_states,
-                    True  # assumed_state
+                    True,  # assumed_state
                 )
 
         if state in [STATE_ON, HVAC_MODE_OFF]:
@@ -355,10 +395,8 @@ class SensiboClimate(ClimateDevice):
         """Retrieve latest state."""
         try:
             with async_timeout.timeout(TIMEOUT):
-                data = await self._client.async_get_device(
-                    self._id, _FETCH_FIELDS)
+                data = await self._client.async_get_device(self._id, _FETCH_FIELDS)
                 self._do_update(data)
-        except (aiohttp.client_exceptions.ClientError,
-                pysensibo.SensiboError):
-            _LOGGER.warning('Failed to connect to Sensibo servers.')
+        except (aiohttp.client_exceptions.ClientError, pysensibo.SensiboError):
+            _LOGGER.warning("Failed to connect to Sensibo servers.")
             self._available = False
