@@ -9,8 +9,8 @@ from .const import CONF_GATEWAY_ID
 
 _LOGGER = logging.getLogger(__name__)
 
-IKEA = 'IKEA of Sweden'
-TRADFRI_SWITCH_MANAGER = 'Tradfri Switch Manager'
+IKEA = "IKEA of Sweden"
+TRADFRI_SWITCH_MANAGER = "Tradfri Switch Manager"
 
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
@@ -24,7 +24,8 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     switches = [dev for dev in devices if dev.has_socket_control]
     if switches:
         async_add_entities(
-            TradfriSwitch(switch, api, gateway_id) for switch in switches)
+            TradfriSwitch(switch, api, gateway_id) for switch in switches
+        )
 
 
 class TradfriSwitch(SwitchDevice):
@@ -54,14 +55,12 @@ class TradfriSwitch(SwitchDevice):
         info = self._switch.device_info
 
         return {
-            'identifiers': {
-                (TRADFRI_DOMAIN, self._switch.id)
-            },
-            'name': self._name,
-            'manufacturer': info.manufacturer,
-            'model': info.model_number,
-            'sw_version': info.firmware_version,
-            'via_device': (TRADFRI_DOMAIN, self._gateway_id),
+            "identifiers": {(TRADFRI_DOMAIN, self._switch.id)},
+            "name": self._name,
+            "manufacturer": info.manufacturer,
+            "model": info.model_number,
+            "sw_version": info.firmware_version,
+            "via_device": (TRADFRI_DOMAIN, self._gateway_id),
         }
 
     async def async_added_to_hass(self):
@@ -100,16 +99,18 @@ class TradfriSwitch(SwitchDevice):
     def _async_start_observe(self, exc=None):
         """Start observation of switch."""
         from pytradfri.error import PytradfriError
+
         if exc:
             self._available = False
             self.async_schedule_update_ha_state()
-            _LOGGER.warning("Observation failed for %s", self._name,
-                            exc_info=exc)
+            _LOGGER.warning("Observation failed for %s", self._name, exc_info=exc)
 
         try:
-            cmd = self._switch.observe(callback=self._observe_update,
-                                       err_callback=self._async_start_observe,
-                                       duration=0)
+            cmd = self._switch.observe(
+                callback=self._observe_update,
+                err_callback=self._async_start_observe,
+                duration=0,
+            )
             self.hass.async_create_task(self._api(cmd))
         except PytradfriError as err:
             _LOGGER.warning("Observation failed, trying again", exc_info=err)
