@@ -53,8 +53,11 @@ from homeassistant.const import (
 )
 from homeassistant.core import DOMAIN as CONF_CORE, SOURCE_YAML, HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
-from homeassistant.loader import Integration, async_get_integration, IntegrationNotFound
-from homeassistant.requirements import async_process_requirements
+from homeassistant.loader import Integration, IntegrationNotFound
+from homeassistant.requirements import (
+    async_get_integration_with_requirements,
+    RequirementsNotFound,
+)
 from homeassistant.util.yaml import load_yaml, SECRET_YAML
 from homeassistant.util.package import is_docker_env
 import homeassistant.helpers.config_validation as cv
@@ -319,7 +322,8 @@ async def async_hass_config_yaml(hass: HomeAssistant) -> Dict:
         config = load_yaml_config_file(path)
         return config
 
-    config = await hass.async_add_executor_job(_load_hass_yaml_config)
+    # Not using async_add_executor_job because this is an internal method.
+    config = await hass.loop.run_in_executor(None, _load_hass_yaml_config)
     core_config = config.get(CONF_CORE, {})
     await merge_packages_config(hass, config, core_config.get(CONF_PACKAGES, {}))
     return config
@@ -628,10 +632,9 @@ def _recursive_merge(conf: Dict[str, Any], package: Dict[str, Any]) -> Union[boo
             error = _recursive_merge(conf=conf[key], package=pack_conf)
 
         elif isinstance(pack_conf, list):
-            if not pack_conf:
-                continue
-            conf[key] = cv.ensure_list(conf.get(key))
-            conf[key].extend(cv.ensure_list(pack_conf))
+            conf[key] = cv.remove_falsy(
+                cv.ensure_list(conf.get(key)) + cv.ensure_list(pack_conf)
+            )
 
         else:
             if conf.get(key) is not None:
@@ -658,45 +661,25 @@ async def merge_packages_config(
             domain = comp_name.split(" ")[0]
 
             try:
-                integration = await async_get_integration(hass, domain)
-            except IntegrationNotFound:
-                _log_pkg_error(pack_name, comp_name, config, "does not exist")
-                continue
-
-            if (
-                not hass.config.skip_pip
-                and integration.requirements
-                and not await async_process_requirements(
-                    hass, integration.domain, integration.requirements
+                integration = await async_get_integration_with_requirements(
+                    hass, domain
                 )
-            ):
-                _log_pkg_error(
-                    pack_name, comp_name, config, "unable to install all requirements"
-                )
-                continue
-
-            try:
                 component = integration.get_component()
-            except ImportError:
-                _log_pkg_error(pack_name, comp_name, config, "unable to import")
+            except (IntegrationNotFound, RequirementsNotFound, ImportError) as ex:
+                _log_pkg_error(pack_name, comp_name, config, str(ex))
                 continue
 
-            if hasattr(component, "PLATFORM_SCHEMA"):
-                if not comp_conf:
-                    continue  # Ensure we dont add Falsy items to list
-                config[comp_name] = cv.ensure_list(config.get(comp_name))
-                config[comp_name].extend(cv.ensure_list(comp_conf))
-                continue
+            merge_list = hasattr(component, "PLATFORM_SCHEMA")
 
-            if hasattr(component, "CONFIG_SCHEMA"):
+            if not merge_list and hasattr(component, "CONFIG_SCHEMA"):
                 merge_type, _ = _identify_config_schema(component)
+                merge_list = merge_type == "list"
 
-                if merge_type == "list":
-                    if not comp_conf:
-                        continue  # Ensure we dont add Falsy items to list
-                    config[comp_name] = cv.ensure_list(config.get(comp_name))
-                    config[comp_name].extend(cv.ensure_list(comp_conf))
-                    continue
+            if merge_list:
+                config[comp_name] = cv.remove_falsy(
+                    cv.ensure_list(config.get(comp_name)) + cv.ensure_list(comp_conf)
+                )
+                continue
 
             if comp_conf is None:
                 comp_conf = OrderedDict()
@@ -775,26 +758,15 @@ async def async_process_component_config(
             continue
 
         try:
-            p_integration = await async_get_integration(hass, p_name)
-        except IntegrationNotFound:
-            continue
-
-        if (
-            not hass.config.skip_pip
-            and p_integration.requirements
-            and not await async_process_requirements(
-                hass, p_integration.domain, p_integration.requirements
-            )
-        ):
-            _LOGGER.error(
-                "Unable to install all requirements for %s.%s", domain, p_name
-            )
+            p_integration = await async_get_integration_with_requirements(hass, p_name)
+        except (RequirementsNotFound, IntegrationNotFound) as ex:
+            _LOGGER.error("Platform error: %s - %s", domain, ex)
             continue
 
         try:
             platform = p_integration.get_platform(domain)
         except ImportError:
-            _LOGGER.exception("Failed to get platform %s.%s", domain, p_name)
+            _LOGGER.exception("Platform error: %s", domain)
             continue
 
         # Validate platform specific schema
