@@ -283,14 +283,10 @@ async def async_process_deps_reqs(
     ):
         raise HomeAssistantError("Could not set up all dependencies.")
 
-    if (
-        not hass.config.skip_pip
-        and integration.requirements
-        and not await requirements.async_process_requirements(
+    if not hass.config.skip_pip and integration.requirements:
+        await requirements.async_process_requirements(
             hass, integration.domain, integration.requirements
         )
-    ):
-        raise HomeAssistantError("Could not install all requirements.")
 
     processed.add(integration.domain)
 
